import gradio as gr
import torch
from transformers import pipeline
from PIL import ImageDraw

# Load your model here
pipe = pipeline(
    task="object-detection", 
    model="facebook/detr-resnet-50",
    revision="no_timm"
)

def predict(image):
    # Place your code here
    results = pipe(image)
    
    label = {}
    result_image = image.copy()
    draw = ImageDraw.Draw(result_image)
    for i in range(len(results)):
        name = results[i]['label']
        score = results[i]['score']
        label[name] = score  
        
        box = results[i]['box']
        draw.rectangle([(box['xmin'], box['ymin']), (box['xmax'], box['ymax'])], outline='red', width=2)
        label_str = f"{name}: {round(score, 3)}"
        draw.text((box['xmin'], box['ymin']), label_str, color='r', backgroundcolor='white', fontsize=8)

    return result_image, label

inputs = gr.Image(type="pil")
outputs = [gr.Image(), gr.Label()]
examples = []

gr.Interface(fn=predict, inputs=inputs, outputs=outputs, examples=examples).launch(auth=("user", "user"))
